@@ -2,7 +2,7 @@ from typing import Callable, List, Tuple
 
 from palett import Preset
 from palett.presets import FRESH, PLANET
-from texting import COLF, RTSP
+from texting import COLF, ELLIP, RTSP
 from texting.enum.brackets import BRC, NONE
 
 from pyspare.deco.deco_entries.deco_entries import deco_entries
@@ -19,9 +19,10 @@ def deco_dict(
         delim: str = COLF,
         bracket: int = BRC,
         ansi: bool = False,
-        dash: str = RTSP
+        dash: str = RTSP,
+        rule: tuple = (ELLIP, ELLIP)
 ):
-    if not isinstance(lex, dict) or not dict: return str(lex)
+    if not isinstance(lex, dict) or not len(lex): return str(lex)
     return deco_entries(list(lex.items()),
                         key_read=key_read,
                         read=read,
@@ -33,4 +34,5 @@ def deco_dict(
                         bracket=bracket,
                         inner_bracket=NONE,
                         ansi=ansi,
-                        dash=dash)
+                        dash=dash,
+                        rule=rule)
